@@ -22,6 +22,4 @@
  *
  */
 
-void level_editor_beautify_grass_tiles(level *);
-
-
+void level_editor_beautify_grass_tiles(level *, int, int, int, int);
