@@ -1,5 +1,4 @@
 
-
 /* 
  *
  *   Copyright (c) 2009 Arthur Huillet
@@ -24,11 +23,11 @@
  *
  */
 
-int leveleditor_select_input(SDL_Event *event);
+int leveleditor_select_input(SDL_Event * event);
 int leveleditor_select_display();
 
 int selection_empty();
-void * single_tile_selection();
+void *single_tile_selection(int);
 int element_in_selection(void *);
 
 int level_editor_can_cycle_obs();
