@@ -37,7 +37,6 @@
 
 /* some defines */
 
-
 #define CONNECTION_STRING	"c: "
 #define WHITE_SPACE 		" \t"
 #define MAP_BEGIN_STRING	"beginning_of_map"
@@ -54,7 +53,7 @@
 #define ITEM_NAME_STRING "it: n=\""
 #define ITEM_POS_X_STRING " X="
 #define ITEM_POS_Y_STRING " Y="
-#define ITEM_AC_BONUS_STRING " AC="
+#define ITEM_DR_BONUS_STRING " DR="
 #define ITEM_DAMAGE_STRING " Dmg="
 #define ITEM_DAMAGE_MODIFIER_STRING " DmgMod="
 #define ITEM_MAX_DURATION_STRING " MDur="
@@ -73,10 +72,9 @@
 #define ITEM_BONUS_TO_HEALTH_RECOVERY_STRING " StrHealthRecovery="
 #define ITEM_BONUS_TO_MANA_RECOVERY_STRING " StrManaRecovery="
 #define ITEM_BONUS_TO_TOHIT_STRING " StrToHit="
-#define ITEM_BONUS_TO_ACDAM_STRING " StrACDam="
+#define ITEM_BONUS_TO_DRDAM_STRING " StrDRDam="
 #define ITEM_BONUS_TO_RESELE_STRING " ResEle="
 #define ITEM_BONUS_TO_RESFIR_STRING " ResFir="
-#define ITEM_BONUS_TO_RESFOR_STRING " ResFor="
 #define ITEM_IS_IDENTIFIED_STRING " IsIdent="
 #define CHEST_ITEMS_SECTION_BEGIN_STRING "pchestinfolvl"
 #define CHEST_ITEMS_SECTION_END_STRING "/pchestinfolvl"
@@ -99,11 +97,6 @@
 #define OBSTACLE_LABEL_STATES_STRING "states=\""
 #define INDEX_OF_OBSTACLE_NAME "obstacle_label.index="
 
-#define OBSTACLE_DESCRIPTION_BEGIN_STRING "pobsdescinfolvl"
-#define OBSTACLE_DESCRIPTION_END_STRING "/pobsdescinfolvl"
-#define INDEX_OF_OBSTACLE_DESCRIPTION "obstacle_description.index="
-#define OBSTACLE_DESCRIPTION_ANNOUNCE_STRING "obstacle_description_text=\""
-
 #define BIG_MAP_INSERT_SECTION_BEGIN_STRING "Start of big graphics insert information for this level"
 #define BIG_MAP_INSERT_SECTION_END_STRING "End of big graphics insert information for this level"
 #define POSITION_X_OF_BIG_MAP_INSERT_STRING "BigGraphicsInsertPosX="
@@ -120,14 +113,6 @@
 #define OBSTACLE_LABEL_INDEX_STRING "l"
 #define OBSTACLE_DESCRIPTION_INDEX_STRING "d"
 
-
-
-//--------------------
-// Distance, where door opens 
-//
-#define DOOROPENDIST2 (2.0)
-#define DOOROPENDIST2_FOR_DROIDS (1.0)
-
 //--------------------
 // How big is the margin the walls have as far as collisions are concerned.
 //
@@ -148,16 +133,14 @@
 #define H_RANDSPACE		WALLPASS
 #define H_RANDBREITE		(5/64.0)
 
-enum _colornames
-{
-  PD_RED,
-  PD_YELLOW,
-  PD_GREEN,
-  PD_GRAY,
-  PD_BLUE,
-  PD_GREENBLUE,
-  PD_DARK
+enum _colornames {
+	PD_RED,
+	PD_YELLOW,
+	PD_GREEN,
+	PD_GRAY,
+	PD_BLUE,
+	PD_GREENBLUE,
+	PD_DARK
 };
 
-
 #endif
